import setuptools

setuptools.setup(
    name="mutian-core",
    version="1.0.0",
    author="mutian",
    author_email="mutian-xiangcai@outlook.com",
    description="",
    url="http://baidu.com/",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
